//
//	LogAsErrorEvent v 2.0
//	Russell Lowke, February 4th 2010
//	for use with ActionScript 3 (AS3, Flex SDK 3.2, Flash Player 9)
// 
//	Copyright (c) 2009-2010 Russell Lowke
//	see http://www.lowkemedia.com for more information
// 
//	Permission is hereby granted, free of charge, to any person obtaining a 
//	copy of this software and associated documentation files (the "Software"), 
//	to deal in the Software without restriction, including without limitation 
//	the rights to use, copy, modify, merge, publish, distribute, sublicense, 
//	and/or sell copies of the Software, and to permit persons to whom the 
//	Software is furnished to do so, subject to the following conditions:
// 
//	The above copyright notice and this permission notice shall be included in 
//	all copies or substantial portions of the Software.
// 
//	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
//	IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
//	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
//	AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//	LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//	FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS 
//	IN THE SOFTWARE. 
//
//

package com.lowke.utils.logAs.events {
	
	import com.lowke.utils.logAs.LogAs;
	
	import flash.events.Event;
	
	public class LogAsEvent extends Event {
		
		// event name
		public static const LOG_AS_EVENT:String = "logAs_Event";
		
		// errorLevel types
		public static const SEVERE:uint	 = 1;
		public static const WARNING:uint = 2;
		public static const INFO:uint	 = 3;
		public static const DEBUG:uint	 = 4;
		
		private var _message:String;		// message being logged
		private var _level:uint;			// log level of message
		private var _id:uint;				// id of log message
		
		public function LogAsEvent(type:String, 
								message:String, 
								  level:uint, 
									 id:uint = 0) {
			super(type);
			
			_message = message;
			_level = level;
			_id = id;
		}
		
		public override function clone():Event {
			return new LogAsEvent(type, message, level, id);
		}
		
		
		public override function toString():String {
			
			var str:String;
			switch (_level) {
				case SEVERE:	str = "SEVERE";		break;
				case WARNING:	str = "WARNING";	break;
				case INFO:		str = "INFO";		break;
				case DEBUG:		str = "DEBUG";		break;
			}
			
			return str + (id ? " #" + id : "") + ": " + message;
		}
		

		// accessors and mutators
		public function get message():String { 
			return _message;
		}
		
		public function get level():uint { 
			return _level;
		}
		
		public function get id():uint { 
			return _id;
		}
	}
}